==> buzz_booster-0.2.2.tar.gz: ios/Classes/BuzzBoosterPlugin.m <==
#import "BuzzBoosterPlugin.h"
#import "FLCampaignFloatingActionButtonFactory+View.h"
#import "FLCampaignEntryViewFactory+View.h"

@implementation BuzzBoosterPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"buzz_booster"
            binaryMessenger:[registrar messenger]];
  BuzzBoosterPlugin* instance = [[BuzzBoosterPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];

  FLCampaignFloatingActionButtonFactory* campaignFloatingActionButtonFactory =
      [[FLCampaignFloatingActionButtonFactory alloc] initWithMessenger:registrar.messenger];
  [registrar registerViewFactory:campaignFloatingActionButtonFactory withId:@"CampaignFloatingActionButton"];
  FLCampaignEntryViewFactory* campaignEntryViewFactory =
      [[FLCampaignEntryViewFactory alloc] initWithMessenger:registrar.messenger];
  [registrar registerViewFactory:campaignEntryViewFactory withId:@"CampaignEntryView"];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"init" isEqualToString:call.method]) {
    NSString *appKey = call.arguments[@"iosAppKey"];
    if (appKey != nil && ![appKey isKindOfClass:[NSNull class]]) {
      BSTConfig *config = [BSTConfig configWithBlock:^(BSTConfigBuilder * _Nonnull builder) {
        builder.appKey = appKey;
      }];
      [BuzzBooster initializeWithConfig:config];
      result(nil);
    } else {
      FlutterError *error = [FlutterError errorWithCode:@"400" message:@"iOSAppKey is required" details:nil];
      result(error);
    }
  } else if ([@"startService" isEqualToString:call.method]){
    [BuzzBooster startService];
    result(nil);
  } else if ([@"setUserId" isEqualToString:call.method]) {
    NSString * _Nullable userId = call.arguments[@"userId"];
    if (userId != nil && ![userId isKindOfClass:[NSNull class]]) {
      [BuzzBooster setUserId:userId];
    } else {
      [BuzzBooster setUserId:nil];
    }
    result(nil);
  } else if ([@"sendEvent" isEqualToString:call.method]){
    NSString *eventName = call.arguments[@"eventName"];
    NSDictionary * _Nullable eventValues = call.arguments[@"eventValues"];
    if (eventValues != nil && ![eventValues isKindOfClass:[NSNull class]]) {
      [BuzzBooster sendEventWithEventName:eventName
                              eventValues:eventValues];
    } else {
      [BuzzBooster sendEventWithEventName:eventName];
    }
    result(nil);
  } else if ([@"showInAppMessage" isEqualToString:call.method]){
    UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
    [BuzzBooster showInAppMessageWithViewController:viewController];
    result(nil);
  } else if ([@"showCampaign" isEqualToString:call.method]){
    UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
    [BuzzBooster showCampaignWithViewController:viewController];
    result(nil);
  } else if ([@"showSpecificCampaign" isEqualToString:call.method]){
    UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
    NSString *campaignType = call.arguments[@"campaignType"];
    if (campaignType != nil && [campaignType isEqualToString:@"attendance"]) {
      [BuzzBooster showCampaignWithViewController:viewController type:BSTCampaignTypeAttendance];
    }
    result(nil);
  }else {
    result(FlutterMethodNotImplemented);
  }
}

@end

==> buzz_booster-1.11.2.tar.gz: ios/Classes/BuzzBoosterPlugin.m <==
#import "BuzzBoosterPlugin.h"
#import "FLCampaignFloatingActionButtonFactory+View.h"
#import "FLCampaignEntryViewFactory+View.h"

static NSString *const kEventsChannel = @"buzz_booster/link";

@interface BuzzBoosterPlugin () <FlutterStreamHandler>

@end

@implementation BuzzBoosterPlugin {
  FlutterEventSink _eventSink;
}

+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"buzz_booster"
            binaryMessenger:[registrar messenger]];
  BuzzBoosterPlugin* instance = [[BuzzBoosterPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];

  FlutterEventChannel *chargingChannel = [FlutterEventChannel eventChannelWithName:kEventsChannel
                                                                   binaryMessenger:[registrar messenger]];
  [chargingChannel setStreamHandler:instance];

  FLCampaignFloatingActionButtonFactory* campaignFloatingActionButtonFactory =
      [[FLCampaignFloatingActionButtonFactory alloc] initWithMessenger:registrar.messenger];
  [registrar registerViewFactory:campaignFloatingActionButtonFactory withId:@"CampaignFloatingActionButton"];
  FLCampaignEntryViewFactory* campaignEntryViewFactory =
      [[FLCampaignEntryViewFactory alloc] initWithMessenger:registrar.messenger];
  [registrar registerViewFactory:campaignEntryViewFactory withId:@"CampaignEntryView"];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"init" isEqualToString:call.method]) {
    NSString *appKey = call.arguments[@"iosAppKey"];
    if (appKey != nil && ![appKey isKindOfClass:[NSNull class]]) {
      BSTConfig *config = [BSTConfig configWithBlock:^(BSTConfigBuilder * _Nonnull builder) {
        builder.appKey = appKey;
      }];
      [BuzzBooster initializeWithConfig:config];
      [BuzzBooster setCampaignEventDelegate:self];
      result(nil);
    } else {
      FlutterError *error = [FlutterError errorWithCode:@"400" message:@"iOSAppKey is required" details:nil];
      result(error);
    }
  } else if ([@"startService" isEqualToString:call.method]){
    [BuzzBooster startService];
    result(nil);
  } else if ([@"setUserId" isEqualToString:call.method]) {
    NSString * _Nullable userId = call.arguments[@"userId"];
    if (userId != nil && ![userId isKindOfClass:[NSNull class]]) {
      [BuzzBooster setUserId:userId];
    } else {
      [BuzzBooster setUserId:nil];
    }
    result(nil);
  } else if ([@"sendEvent" isEqualToString:call.method]){
    NSString *eventName = call.arguments[@"eventName"];
    NSDictionary * _Nullable eventValues = call.arguments[@"eventValues"];
    if (eventValues != nil && ![eventValues isKindOfClass:[NSNull class]]) {
      [BuzzBooster sendEventWithEventName:eventName
                              eventValues:eventValues];
    } else {
      [BuzzBooster sendEventWithEventName:eventName];
    }
    result(nil);
  } else if ([@"showInAppMessage" isEqualToString:call.method]){
    UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
    [BuzzBooster showInAppMessageWithViewController:viewController];
    result(nil);
  } else if ([@"showCampaign" isEqualToString:call.method]){
    UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
    [BuzzBooster showCampaignWithViewController:viewController];
    result(nil);
  } else if ([@"showSpecificCampaign" isEqualToString:call.method]){
    UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
    NSString *campaignType = call.arguments[@"campaignType"];
    if (campaignType != nil) {
      if ([campaignType isEqualToString:@"attendance"]) {
        [BuzzBooster showCampaignWithViewController:viewController type:BSTCampaignTypeAttendance];
      } else if ([campaignType isEqualToString:@"referral"]) {
        [BuzzBooster showCampaignWithViewController:viewController type:BSTCampaignTypeReferral];
      }
    }
    result(nil);
  } else {
    result(FlutterMethodNotImplemented);
  }
}

#pragma mark --FlutterStreamHandler
- (FlutterError *_Nullable)onListenWithArguments:(id _Nullable)arguments
                                       eventSink:(nonnull FlutterEventSink)eventSink {
  _eventSink = eventSink;
  return nil;
}

- (FlutterError *_Nullable)onCancelWithArguments:(id _Nullable)arguments {
  _eventSink = nil;
  return nil;
}

#pragma mark --DeepLink
- (void)customCampaignActionButtonClickedWithUrl:(NSString *)url {
  UIViewController *viewController = [UIApplication sharedApplication].delegate.window.rootViewController;
  [viewController dismissViewControllerAnimated:NO completion:nil];
  if (_eventSink) {
    _eventSink(url);
  }
}

@end
